pub fn host_bound_hosts(hosting: IntegrationHosting) -> &'static [&'static str]Expand description
Hosts declared for a host-bound provider (empty for managed). These are the substrate keys that count as host overrides for this provider’s config.
pub fn host_bound_hosts(hosting: IntegrationHosting) -> &'static [&'static str]Hosts declared for a host-bound provider (empty for managed). These are the substrate keys that count as host overrides for this provider’s config.