pub fn bool_optional(
ctx: &ProvisionContext<'_>,
config: &BTreeMap<String, Value>,
key: &str,
) -> Result<Option<bool>, IntegrationError>Expand description
Read an optional boolean field from the effective config.
pub fn bool_optional(
ctx: &ProvisionContext<'_>,
config: &BTreeMap<String, Value>,
key: &str,
) -> Result<Option<bool>, IntegrationError>Read an optional boolean field from the effective config.