pub fn bool_required(
ctx: &ProvisionContext<'_>,
config: &BTreeMap<String, Value>,
key: &str,
) -> Result<bool, IntegrationError>Expand description
Read a required boolean field from the effective config.
pub fn bool_required(
ctx: &ProvisionContext<'_>,
config: &BTreeMap<String, Value>,
key: &str,
) -> Result<bool, IntegrationError>Read a required boolean field from the effective config.