pub fn int_optional(
ctx: &ProvisionContext<'_>,
config: &BTreeMap<String, Value>,
key: &str,
) -> Result<Option<i64>, IntegrationError>Expand description
Read an optional integer field from the effective config.
pub fn int_optional(
ctx: &ProvisionContext<'_>,
config: &BTreeMap<String, Value>,
key: &str,
) -> Result<Option<i64>, IntegrationError>Read an optional integer field from the effective config.