pub fn interp_optional(
ctx: &ProvisionContext<'_>,
config: &BTreeMap<String, Value>,
key: &str,
) -> Result<Option<String>, IntegrationError>Expand description
Read an optional string field and interpolate it when present.
pub fn interp_optional(
ctx: &ProvisionContext<'_>,
config: &BTreeMap<String, Value>,
key: &str,
) -> Result<Option<String>, IntegrationError>Read an optional string field and interpolate it when present.